@@ -4,6 +4,7 @@ import inspect
 import re
 from functools import partial
 from json import JSONEncoder
+from pathlib import Path, PurePath
 
 from beartype import beartype
 from beartype.typing import Any, Dict, Union
@@ -13,8 +14,8 @@ _RE_MEMORY_ADDRESS = re.compile(r' at 0x[^>]+>')
 
 
 @beartype
-def serialize_if_callable(value: Any) -> Any:
-    """Serialize value with the memory address removed (if a function).
+def coerce_if_known_type(value: Any) -> Any:
+    """Coerce value to standard primitive if known.
 
     Args:
         value: value to serialize
@@ -27,6 +28,9 @@ def serialize_if_callable(value: Any) -> Any:
         # Remove hex memory address from partial function signature
         return _RE_MEMORY_ADDRESS.sub('(..)>', str(value))  # noqa: PD005
 
+    if isinstance(value, (Path, PurePath)):
+        return value.as_posix()
+
     return value
 
 
@@ -44,7 +48,7 @@ def recursive_serialize(value: Any) -> Union[Dict[str, Any], str]:
     if isinstance(value, dict) and value:
         return {_k: recursive_serialize(_v) for _k, _v in value.items()}
 
-    return str(serialize_if_callable(value))
+    return str(coerce_if_known_type(value))
 
 
 class CacheAssertSerializer(JSONEncoder):
@@ -62,6 +66,6 @@ class CacheAssertSerializer(JSONEncoder):
         for _type, converter in encodable_types.items():
             if isinstance(obj, _type):
                 return converter(obj)
-        obj = serialize_if_callable(obj)
+        obj = coerce_if_known_type(obj)
 
         return obj if isinstance(obj, str) else JSONEncoder.default(self, obj)
