@@ -1,17 +1,17 @@
 """Pytest Plugin."""
 
 import inspect
-import re
 from functools import partial
 from pathlib import Path
 
 import pytest
 from _pytest.fixtures import FixtureRequest
 from beartype import beartype
-from beartype.typing import Any, Callable, Dict, Union
+from beartype.typing import Any, Callable, Dict
 
 from . import main
 from ._check_assert.constants import DEF_CACHE_DIR_KEY, DEF_CACHE_DIR_NAME
+from ._check_assert.serializer import recursive_serialize
 
 
 @pytest.fixture()
@@ -20,27 +20,6 @@ def cache_assert_config() -> Dict[str, Any]:
     return {}  # noqa: DAR201
 
 
-@beartype
-def _serialize(value: Any) -> Union[dict, str]:
-    """Recursive serialization function.
-
-    Args:
-        value: value to serialize
-
-    Returns:
-        Union[dict, str]: JSON-safe data
-
-    """
-    if isinstance(value, dict) and value:
-        return {_k: _serialize(_v) for _k, _v in value.items()}
-
-    if inspect.isfunction(value) or isinstance(value, partial):
-        # Remove hex memory address from partial function signature
-        return re.sub(r' at 0x[^>]+>', '(..)>', str(value))
-
-    return str(value)
-
-
 @beartype
 def _calculate_metadata(request: FixtureRequest, rel_test_file: Path) -> dict:
     """Calculate metadata.
@@ -56,7 +35,7 @@ def _calculate_metadata(request: FixtureRequest, rel_test_file: Path) -> dict:
     test_name = (f'{request.cls.__name__}/' if request.cls else '') + request.node.originalname
     test_params = [*inspect.signature(request.node.function).parameters.keys()]
     raw_args = {key: value for key, value in request.node.funcargs.items() if key in test_params}
-    func_args = {key: _serialize(value) for key, value in raw_args.items()}
+    func_args = {key: recursive_serialize(value) for key, value in raw_args.items()}
     return {'test_file': rel_test_file.as_posix(), 'test_name': test_name, 'func_args': func_args}
 
 
